==> WPyrogram-2.0.135-py3-none-any.whl: pyrogram/raw/functions/payments/__init__.py <==
#  Pyrogram - Telegram MTProto API Client Library for Python
#  Copyright (C) 2017-present Dan <https://github.com/delivrance>
#
#  This file is part of Pyrogram.
#
#  Pyrogram is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Lesser General Public License as published
#  by the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#
#  Pyrogram is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Lesser General Public License for more details.
#
#  You should have received a copy of the GNU Lesser General Public License
#  along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.

# # # # # # # # # # # # # # # # # # # # # # # #
#               !!! WARNING !!!               #
#          This is a generated file!          #
# All changes made in this file will be lost! #
# # # # # # # # # # # # # # # # # # # # # # # #

from .get_payment_form import GetPaymentForm
from .get_payment_receipt import GetPaymentReceipt
from .validate_requested_info import ValidateRequestedInfo
from .send_payment_form import SendPaymentForm
from .get_saved_info import GetSavedInfo
from .clear_saved_info import ClearSavedInfo
from .get_bank_card_data import GetBankCardData
from .export_invoice import ExportInvoice
from .assign_app_store_transaction import AssignAppStoreTransaction
from .assign_play_market_transaction import AssignPlayMarketTransaction
from .can_purchase_premium import CanPurchasePremium
from .get_premium_gift_code_options import GetPremiumGiftCodeOptions
from .check_gift_code import CheckGiftCode
from .apply_gift_code import ApplyGiftCode
from .get_giveaway_info import GetGiveawayInfo
from .launch_prepaid_giveaway import LaunchPrepaidGiveaway

==> WPyrogram-2.0.151-py3-none-any.whl: pyrogram/raw/functions/payments/__init__.py <==
#  Pyrogram - Telegram MTProto API Client Library for Python
#  Copyright (C) 2017-present Dan <https://github.com/delivrance>
#
#  This file is part of Pyrogram.
#
#  Pyrogram is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Lesser General Public License as published
#  by the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#
#  Pyrogram is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Lesser General Public License for more details.
#
#  You should have received a copy of the GNU Lesser General Public License
#  along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.

# # # # # # # # # # # # # # # # # # # # # # # #
#               !!! WARNING !!!               #
#          This is a generated file!          #
# All changes made in this file will be lost! #
# # # # # # # # # # # # # # # # # # # # # # # #

from .get_payment_form import GetPaymentForm
from .get_payment_receipt import GetPaymentReceipt
from .validate_requested_info import ValidateRequestedInfo
from .send_payment_form import SendPaymentForm
from .get_saved_info import GetSavedInfo
from .clear_saved_info import ClearSavedInfo
from .get_bank_card_data import GetBankCardData
from .export_invoice import ExportInvoice
from .assign_app_store_transaction import AssignAppStoreTransaction
from .assign_play_market_transaction import AssignPlayMarketTransaction
from .can_purchase_premium import CanPurchasePremium
from .get_premium_gift_code_options import GetPremiumGiftCodeOptions
from .check_gift_code import CheckGiftCode
from .apply_gift_code import ApplyGiftCode
from .get_giveaway_info import GetGiveawayInfo
from .launch_prepaid_giveaway import LaunchPrepaidGiveaway
from .get_stars_topup_options import GetStarsTopupOptions
from .get_stars_status import GetStarsStatus
from .get_stars_transactions import GetStarsTransactions
from .send_stars_form import SendStarsForm
from .refund_stars_charge import RefundStarsCharge
from .get_stars_revenue_stats import GetStarsRevenueStats
from .get_stars_revenue_withdrawal_url import GetStarsRevenueWithdrawalUrl
from .get_stars_revenue_ads_account_url import GetStarsRevenueAdsAccountUrl
from .get_stars_transactions_by_id import GetStarsTransactionsByID
from .get_stars_gift_options import GetStarsGiftOptions
from .get_stars_subscriptions import GetStarsSubscriptions
from .change_stars_subscription import ChangeStarsSubscription
from .fulfill_stars_subscription import FulfillStarsSubscription
from .get_stars_giveaway_options import GetStarsGiveawayOptions
from .get_star_gifts import GetStarGifts
from .get_user_star_gifts import GetUserStarGifts
from .save_star_gift import SaveStarGift
from .convert_star_gift import ConvertStarGift
